@@ -112,8 +112,8 @@ class EsOp():
         else:
             return '未查到'
 
-    def index_search(self,index_name,body):
-        result =  self.conn.search(index=index_name,body=body)
+    def index_search(self,index_name,body,size=1000):
+        result =  self.conn.search(index=index_name,size=size,body=body)
         return self.index_result_dict(result)
     def index_search_all(self,index_name,pn=1,size=10000,doc_type=''):
         body = {
